@@ -73,6 +73,12 @@ class ModifyDBClusterMigrationRequest(RpcRequest):
 	def set_SourceRDSDBInstanceId(self,SourceRDSDBInstanceId):
 		self.add_query_param('SourceRDSDBInstanceId',SourceRDSDBInstanceId)
 
+	def get_SwapConnectionString(self):
+		return self.get_query_params().get('SwapConnectionString')
+
+	def set_SwapConnectionString(self,SwapConnectionString):
+		self.add_query_param('SwapConnectionString',SwapConnectionString)
+
 	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
